Module api

Module api 

API for TURN servers.

Structs

Transmit
A piece of data that needs to, or has been transmitted

Enums

DelayedMessageOrChannelSend
Transmission data that needs to be constructed before transmit.
SocketAllocateError
Errors that can be conveyed when allocating a socket for a client.
TcpConnectError
Errors that can be conveyed when allocating a socket for a client.
TurnServerPollRet
Return value for poll.

Traits

TurnServerApi
API for TURN servers.