pub enum TcpConnectError {
InsufficientCapacity,
Forbidden,
TimedOut,
Failure,
}Expand description
Errors that can be conveyed when allocating a socket for a client.
Variants
InsufficientCapacity
The server does not have the capacity to handle this request.
Forbidden
Connection is forbidden by local policy.
TimedOut
Timed Out attempting to connect to the specified peer.
Failure
Faild for any other unspecified reason.
Implementations
Sourceimpl TcpConnectError
impl TcpConnectError
Sourcepub fn into_error_code(self) -> u16
pub fn into_error_code(self) -> u16
Convert this error into an error code for the ErrorCode or AddressErrorCode attributes.