Transmit

Struct Transmit 

pub struct Transmit<T>
where T: AsRef<[u8]>,
{ pub data: T, pub transport: TransportType, pub from: SocketAddr, pub to: SocketAddr, }
A piece of data that needs to, or has been transmitted

Fields

data: T

The data blob

transport: TransportType

The transport for the transmission

from: SocketAddr

The source address of the transmission

to: SocketAddr

The destination address of the transmission

Implementations

Source

impl<T> Transmit<T>
where T: AsRef<[u8]>,

pub fn new( data: T, transport: TransportType, from: SocketAddr, to: SocketAddr, ) -> Transmit<T>

Construct a new Transmit with the specifid data and 5-tuple.

pub fn reinterpret_data<O, F>(self, f: F) -> Transmit<O>
where O: AsRef<[u8]>, F: FnOnce(T) -> O,

Reinterpret the data of a Transmit into a different type.

Examples
let local_addr = "10.0.0.1:1000".parse().unwrap();
let remote_addr = "10.0.0.2:2000".parse().unwrap();
let slice = [42; 8];
let transmit = Transmit::new(slice.clone(), TransportType::Udp, local_addr, remote_addr);
// change the data type of the `Transmit` into a `Vec<u8>`.
let transmit = transmit.reinterpret_data(|data| data.to_vec());
assert_eq!(transmit.data, slice.as_slice());
Source

impl Transmit<Data<'_>>

pub fn into_owned<'b>(self) -> Transmit<Data<'b>>

Construct a new owned Transmit from a provided Transmit